# Magento 2 Ajax Layered Navigation

Product filtering is one of the most used features which every customer craves on your online store. To clarify, product filtering is an application that buyers select one or multiple product attributes to search for specific products which match their needs.

On an online store which there is no existence of shopping assistants, customers need nothing but an effective product filtering/searching tool. It would seem strange if your Magento 2 store had no **Layered Navigation** because other e-commerce websites, today, are even trying to enhance their filtering systems to optimize UX on their platforms.

To boost filtering experience for buyers, [Ajax Layered Navigation extension for Magento 2]() allows filtered products to appear immediately after every single filtering action. Hence, there is no seem-to-be-painfully-long waiting time between each filter, and customers will be more likely to enjoy their time shopping on your store. 


## 1. Documentation

- [Installation guide](https://www.mageplaza.com/install-magento-2-extension/)
- [User Guide](https://docs.mageplaza.com/ajax-layered-navigation/index.html)
- [Contribute on Github](https://github.com/mageplaza/magento-2-ajax-layered-navigation)
- [Get Support](https://github.com/mageplaza/magento-2-ajax-layered-navigation/issues)


## 2. FAQs

- **Q: I got an error: Mageplaza_Core has been already defined**

- A: Read solution: https://github.com/mageplaza/module-core/issues/3

- **Q: Is Mageplaza Ajax Layered Navigation extension compatible with Layered Navigation for Magento 2?**

- A: Yes! Ajax Layered Navigation extension is fully compatible with all packages of [Mageplaza Layered navigation](https://www.mageplaza.com/magento-2-layered-navigation-extension/) for Magento 2. This compatibility helps enhance UX for shoppers at the highest level.


## 3. How to install Ajax Layered Navigation extension for Magento 2

### Install via composer (recommend)

Run the following command in Magento 2 root folder:

```
composer require mageplaza/module-ajax-layered-navigation
php bin/magento setup:upgrade
php bin/magento setup:static-content:deploy
```
## 4. Highlight features
### Enhance UX by Ajax Technology

Visually, Ajax plays an amazing role in your store UX improvement because of many advantages. Ajax, according to [Sequetech](https://www.seguetech.com/ajax-technology/), is a method which helps to exchange and update only one or several parts of a web page without reloading the whole site. As a result, the page loading speed is cut down optimally, and this allows your online shoppers to avoid unnecessary waiting time. Ajax Navigation is also an answer to the question “How to keep your clients on your store when the internet connection sucks”. They will no longer need to wait for all the data to be loaded before performing any of other actions on the page.

As **Ajax Layered Navigation** enables pages to prevent performing a full postback, filtering products are more responsive, faster and way more user-friendly. This is how shopping experience is boosted.

### Lightening-fast Ajax Navigation

Filtered products are loaded and displayed nearly immediately after a single filtering performance without waiting for other parts of the page to be reloaded. This allows the important content, which includes products, product images, and other product info, to show up first, and to be ready for buyers to perform further actions.

Ajax Layered Navigation saves a bunch of time for customers. Buyers do not even have to hit any button to start loading filtering results because they are automatically loaded after every single filtering act.  

### Ajax Add to Wishlist

Ajax Layered Navigation extension allows logged-in customers add products to their wishlist, yet still stay on the page without being redirected to the wishlist page.

### Compatible with Layered Navigation

Ajax Layered Navigation extension by Mageplaza is fully compatible with all packages of Magento 2 Layered Navigation extension. This feature implemented to Mageplaza Layered Navigation module is a perfect solution to boost shopping experience to the highest level. 

Even when shopper performs multi-filtering, Ajax Layered still supports to display results nicely, smoothly and lightening-fast.

## 5. User Guide

**Ajax Layered Navigation** features are added to filters and page blocks, which assists users to select each attribute from filters and various categories without reloading the entire page. As a result, it will enhance the user experience, reduce response and server uploading time. This is the new feature of Mageplaza Ajax Layered Navigation which fully compatible with Layered Navigation extension.

The Ajax Layered Navigation tutorial of Mageplaza below will provide detailed instruction on how to use for user interface and how to configure on the admin backend.


### How to Config

From the admin panel, make your way to ``Mageplaza > Layered Navigation > Configuration``

![how to configure](https://i.imgur.com/lKM4Yiz.png)

![configuration](https://i.imgur.com/Opo6NTd.png)

![ajax layered navigation](https://i.imgur.com/8d0Jd3F.gif)

Besides, Ajax Layered supports the functions of Add to wishlist by Ajax for logged-in customers. 
After clicking on Add to wishlist icon on Category Page, customers can continue viewing other products without being navigated to Wishlist Page. 

![ajax layered navigation 2](https://i.imgur.com/8J10AWl.gif)










